@@ -6,10 +6,9 @@ import io
 import numpy as np
 # from release_test.CAD_Recognition.data_load import  load_data, _load_data, _data_normalization, data_normalization, _k_folds
 # from release_test.CAD_Recognition.features import dataset_getmfcc
-# sys.path.append('release/CAD_Recognition/data_load.py')
-# sys.path.append('release/CAD_Recognition/features.py')
-from imgkernelfrancis.data_load import (load_data, load_data_, data_normalization_, data_normalization, k_folds_)
-from imgkernelfrancis.features import (dataset_getmfcc)
+from release.CAD_Recognition.data_load import (load_data, load_data_, data_normalization_, data_normalization, k_folds_, extract_name)
+from release.CAD_Recognition.features import dataset_getmfcc
+from release.CAD_Recognition.devide_no_test import data_transform
 import os
 import tensorflow as tf
 from keras import backend as KTF
@@ -316,8 +315,6 @@ def ecg_metrics_cal(labels, prediction, mode, y_true, isprint=False, patient=Fal
 
 def sub1_model_test(root1, x_test_name, y_test_label, y_test_true_label, scaler, model_path=None):
     # 1.加载测试数据
-    # f = io.open('_config.yaml', 'r', encoding="utf-8")
-    # _config = yaml.load(f)
     print("进入PCG测试")
     x_test, y_test, sample_rate = load_data(root1, x_test_name, y_test_label, 5)
     # 2.提取mfcc特征
@@ -340,8 +337,6 @@ def sub1_model_test(root1, x_test_name, y_test_label, y_test_true_label, scaler,
 
 def sub2_model_test(root2, x_test_name, y_test_label, y_test_true_label, scaler, model_path=None):
     # 1.加载测试数据
-    # f = io.open('_config.yaml', 'r', encoding="utf-8")
-    # _config = yaml.load(f)
     print("进入ECG测试")
     x_test, y_test, sample_rate = load_data_(root2, x_test_name, y_test_label, 5)
     # 2.特征归一化
@@ -361,39 +356,16 @@ def sub2_model_test(root2, x_test_name, y_test_label, y_test_true_label, scaler,
         ecg_metrics_cal(y_test, y_pred, "test", y_test_true_label,isprint=True, patient=True)
     return double_class_results
 
-def threshold_test(data_path, model_list, scaler1, scaler2):
+def threshold_test(data_path, model_list, scaler1, scaler2, ab_num=10, nor_num=10):
     # 分别用不同的k_folds来取出轻风险不同标签的验证数据，但是患者是相同的，只是轻风险标签不同，将数据分别送入两个子分类器进行分类。
-    # f = io.open('_config.yaml', 'r', encoding="utf-8")
-    # _config = yaml.load(f)
-    all_metrics = np.zeros((1, 7))
     matrix = np.zeros((3,3))
-    '''model_list = [["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-0_val_loss-0.59_epoch-40_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_0val_loss-0.40_epoch-239_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-1_val_loss-0.38_epoch-06_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_1val_loss-0.30_epoch-35_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-2_val_loss-0.27_epoch-06_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_2val_loss-0.43_epoch-234_ECG_model.hdf5",],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-3_val_loss-0.52_epoch-07_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_3val_loss-0.48_epoch-243_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-4_val_loss-0.50_epoch-02_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_4val_loss-0.52_epoch-118_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-5_val_loss-0.34_epoch-08_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_5val_loss-0.37_epoch-181_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-6_val_loss-0.40_epoch-09_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_6val_loss-0.38_epoch-62_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-7_val_loss-0.26_epoch-04_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_7val_loss-0.29_epoch-327_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-8_val_loss-0.32_epoch-07_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_8val_loss-0.44_epoch-232_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-9_val_loss-0.53_epoch-02_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_9val_loss-0.48_epoch-34_ECG_model.hdf5"]]'''
-    root_1, x_kf_train_1, y_kf_train_1, x_kf_valid_1, y_kf_valid_1, y_kf_true_train_1, y_kf_true_valid_1 = k_folds_(data_path, 10, sub=1)
-    root_2, x_kf_train_2, y_kf_train_2, x_kf_valid_2, y_kf_valid_2, y_kf_true_train_2, y_kf_true_valid_2 = k_folds_(data_path, 10, sub=2)
-    for i in range(0, 10):
-        print("\033[31mFolds:{:d}===========================================>\033[0m".format(i + 1))
-        sub_1_results = sub1_model_test(root_1, x_kf_valid_1[i], y_kf_valid_1[i], y_kf_true_valid_1[i], scaler1, model_list[0])
-        sub_2_results = sub2_model_test(root_2, x_kf_valid_2[i], y_kf_valid_2[i], y_kf_true_valid_2[i], scaler2, model_list[1])
-        this_martix = decision_fusion(y_kf_true_valid_1[i], sub_1_results, sub_2_results)
-        matrix += this_martix
-        if i == 1: break
-
-    # 11.交叉验证训练指标计算
-    '''all_metrics = np.delete(all_metrics, 0, axis=0)  # 删掉0行
-    macro_metrics = np.mean(all_metrics, axis=0)
-    macro_F1 = 2 * (macro_metrics[3] * macro_metrics[4]) / (macro_metrics[3] + macro_metrics[4])
-    print("\033[32mmacro results:\nAccuracy:{:.3f}%\nSensitivity:{:.3f}%\nSpecificity:{:.3f}%\nPrecision:{:.3f}%\nRecall:{:.3f}%\nG_mean:{:.3f}\nF1:{:.3f}\033[0m".
-        format(macro_metrics[0], macro_metrics[1], macro_metrics[2], macro_metrics[3], macro_metrics[4],
-               macro_metrics[5], macro_F1))'''
+    root_1, x_test_1, y_test_1, y_test_true_1 = extract_name(data_path, sub=1, ab_num=ab_num, nor_num=nor_num)
+    root_2, x_test_2, y_test_2, y_test_true_2 = extract_name(data_path, sub=2, ab_num=ab_num, nor_num=nor_num)
+    # print("\033[31mFolds:{:d}===========================================>\033[0m".format(i + 1))
+    sub_1_results = sub1_model_test(root_1, x_test_1, y_test_1, y_test_true_1, scaler1, model_list[0])
+    sub_2_results = sub2_model_test(root_2, x_test_2, y_test_2, y_test_true_2, scaler2, model_list[1])
+    this_martix = decision_fusion(y_test_true_1, sub_1_results, sub_2_results)
+    matrix += this_martix
     print("交叉验证所有矩阵之和:matrix:\n{:}".format(matrix))
 
 def decision_fusion(y_true, sub_1_results, sub_2_results):
@@ -417,33 +389,43 @@ def decision_fusion(y_true, sub_1_results, sub_2_results):
         labels=[0, 1, 2], target_names=["normal", "mild", "abnormal"])))
     return triple_matrix
 
-def dataset_test(data_path, model_list, scaler1, scaler2):
+def dataset_test(model_list, scaler1, scaler2, ab_num=10, nor_num=10, data_proces=True, *path):
     print("进入测试")
+    if data_proces:
+        assert (len(path)==3)
+        data_path= data_transform(path[0], path[1], path[2])
+    else:
+        assert (len(path) == 1)
+        data_path = path[0]
     with warnings.catch_warnings():
         warnings.filterwarnings('ignore', category=UserWarning)
         warnings.filterwarnings('ignore', category=RuntimeWarning)
-        threshold_test(data_path, model_list, scaler1, scaler2)
+        threshold_test(data_path, model_list, scaler1, scaler2, ab_num=ab_num, nor_num=nor_num)
 
 if __name__ == "__main__":
-    '''model_list = [["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-0_val_loss-0.59_epoch-40_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_0val_loss-0.40_epoch-239_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-1_val_loss-0.38_epoch-06_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_1val_loss-0.30_epoch-35_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-2_val_loss-0.27_epoch-06_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_2val_loss-0.43_epoch-234_ECG_model.hdf5",],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-3_val_loss-0.52_epoch-07_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_3val_loss-0.48_epoch-243_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-4_val_loss-0.50_epoch-02_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_4val_loss-0.52_epoch-118_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-5_val_loss-0.34_epoch-08_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_5val_loss-0.37_epoch-181_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-6_val_loss-0.40_epoch-09_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_6val_loss-0.38_epoch-62_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-7_val_loss-0.26_epoch-04_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_7val_loss-0.29_epoch-327_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-8_val_loss-0.32_epoch-07_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_8val_loss-0.44_epoch-232_ECG_model.hdf5"],
-                  ["E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-9_val_loss-0.53_epoch-02_PCG_model.hdf5","E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release_test/Model/9.21/5_percentage/_folds_9val_loss-0.48_epoch-34_ECG_model.hdf5"]]'''
-    # f = open("_config.yaml", 'r', encoding="utf-8")
-    # _config = yaml.load(f)
-    # computing_resource(_config)
-    # model_fusion()
-
-    scaler1 = pickle.load(open('E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/Model/scaler/scaler_8_30_triple.pkl', 'rb'))
-    scaler2 = pickle.load(open('E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/Model/scaler/scaler_9_11_1,3_4.pkl', 'rb'))
-    data_path = "D:/Dataset/PCG_project/My_data/zaoying/all_zaoying/1,3_4/train"
+    # ===>只需改前三个路径到相应位置,需要把原label文件改成utf8的csv格式读取
+    # 原label所在的路径
+    csv_path = "D:/Dataset/PCG_project/My_data/raw_data/8_17/label/label_before_August.csv"
+    # 原wav所在路径
+    wav_path = "D:/Dataset/PCG_project/My_data/raw_data/8_17/raw_wav"
+    # 想保存到的数据的根路径
+    save_path = "D:/Dataset/PCG_project/My_data/zaoying/all_zaoying/release_test"
+    # 加载特征归一化模型scaler1和scaler2要对应
+    scaler1 = pickle.load(open('scaler1.pkl', 'rb'))
+    scaler2 = pickle.load(open('scaler2.pkl', 'rb'))
+    # 模型路径
     model_list = [
-        "E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/Model/9.21/9.21_5percentage_CL_All_CDG_Model/_folds-7_val_loss-0.26_epoch-04_PCG_model.hdf5",
-        "E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/Model/9.21/5_percentage/_folds_7val_loss-0.29_epoch-327_ECG_model.hdf5"]
-    dataset_test(data_path, model_list, scaler1, scaler2)
+        "E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release/CAD_Recognition/PCG_Model.hdf5",
+        "E:/Postgraduate work/Literature/PCG/PCG_Projects/release_demo/release/CAD_Recognition/ECG_Model.hdf5"
+    ]
+    # 数据路径
+    data_path = "D:/Dataset/PCG_project/My_data/zaoying/all_zaoying/release_test/train"
+    # path = [csv_path, wav_path, save_path]
+    dataset_test(
+        model_list,
+        scaler1,
+        scaler2,
+        10,
+        10,
+        False,
+        *[data_path])
